var Handlebars = require('handlebars'),
	fs = require('fs'),
	path = require('path');

module.exports = function(builder) {
  builder.hook('before scripts', function(pkg, next) {
	var hbs = pkg.config.hbs,
		hbsConfig = pkg.config.hbsConfig || {},
		lang = process.env.HBS_LANG || hbsConfig.defaultLang || 'en-US',
		customHelperPath = hbsConfig.helper || './helper',
		localsPath = hbsConfig.locales || './locales';

	if (pkg.root) {
		var runtime = fs.readFileSync(__dirname + '/handlebars.runtime.js', 'utf8');
		pkg.addFile('scripts', 'handlebars.runtime.js', runtime + ' module.exports = Handlebars;');
		builder.append('require.alias("' + builder.config.name + '/handlebars.runtime.js", "handlebars.runtime.js");');

		var helperBefore = '(function() { var Handlebars = require(\'/handlebars.runtime.js\');',
			helperAfter = '})();',
			files;

		//Add Handlebars helper from src/helper
		if (fs.existsSync(__dirname + '/src/helper')) {
			files = fs.readdirSync(__dirname + '/src/helper');
			files.forEach(function(file) {
				if (/\.js$/.test(file)) {
					var source = fs.readFileSync(__dirname + '/src/helper/' + file);
					builder.append(helperBefore + source + helperAfter);
				}
			});
		}

		//Add custom helper
		customHelperPath = path.resolve(builder.dir, customHelperPath);
		if (fs.existsSync(customHelperPath)) {
			files = fs.readdirSync(customHelperPath);
			files.forEach(function(file) {
				if (/\.js$/.test(file)) {
					var source = fs.readFileSync(path.join(customHelperPath, file));
					builder.append(helperBefore + source + helperAfter);
				}
			});
		}

		if (hbsConfig && hbsConfig.i18n) {
			localsPath = path.resolve(builder.dir, localsPath);
			var locale = require(path.join(localsPath, lang + '.json'));
			builder.append('var __hbsLang = ' + JSON.stringify(locale) + ';');

			var source = fs.readFileSync(__dirname + '/src/i18n.js');
			builder.append('var componentName = "' + builder.config.name + '";');
			builder.append(source);
		}
	}

	if (hbs && hbs.length > 0 ) {
		

		hbs.forEach(function(file, index){
			var src = fs.readFileSync(pkg.path(file), 'utf8'),
				compiled = Handlebars.precompile(src);

			pkg.addFile('scripts', file, 'var Handlebars = require("/' + builder.config.name + '/handlebars.runtime.js"); module.exports = Handlebars.template(' + compiled + ');');
		});
	}

	next();
  });

};